@@ -5,16 +5,21 @@ from click.testing import CliRunner
 
 from ravenpy.cli import aggregate_forcings_to_hrus, generate_grid_weights
 from ravenpy.config.commands import GridWeightsCommand
-from ravenpy.utilities.testdata import get_local_testdata
 
 
 class TestGenerateGridWeights:
-    def test_generate_grid_weights_with_nc_input_and_2d_coords(self, tmp_path):
+    def test_generate_grid_weights_with_nc_input_and_2d_coords(
+        self, tmp_path, get_file
+    ):
         runner = CliRunner()
         output_path = tmp_path / "bla.rvt"
         params = [
-            get_local_testdata("raven-routing-sample/VIC_streaminputs.nc"),
-            get_local_testdata("raven-routing-sample/finalcat_hru_info.zip"),
+            get_file(
+                "raven-routing-sample/VIC_streaminputs.nc",
+            ),
+            get_file(
+                "raven-routing-sample/finalcat_hru_info.zip",
+            ),
             "-o",
             output_path,
         ]
@@ -35,14 +40,18 @@ class TestGenerateGridWeights:
         weight = float(re.search("1 52 (.+)", output).group(1))
         assert abs(weight - 0.2610203097218425) < 1e-04
 
-    def test_generate_grid_weights_with_multiple_subids(self, tmp_path):
+    def test_generate_grid_weights_with_multiple_subids(self, tmp_path, get_file):
         # currently exactly same output as "test_generate_grid_weights_with_nc_input_and_2d_coords"
         # needs a "routing-file-path" with multiple gauges
         runner = CliRunner()
         output_path = tmp_path / "bla.rvt"
         params = [
-            get_local_testdata("raven-routing-sample/VIC_streaminputs.nc"),
-            get_local_testdata("raven-routing-sample/finalcat_hru_info.zip"),
+            get_file(
+                "raven-routing-sample/VIC_streaminputs.nc",
+            ),
+            get_file(
+                "raven-routing-sample/finalcat_hru_info.zip",
+            ),
             "-s",
             "7202",
             "-s",
@@ -67,12 +76,18 @@ class TestGenerateGridWeights:
         weight = float(re.search("1 52 (.+)", output).group(1))
         assert abs(weight - 0.2610203097218425) < 1e-04
 
-    def test_generate_grid_weights_with_nc_input_and_1d_coords(self, tmp_path):
+    def test_generate_grid_weights_with_nc_input_and_1d_coords(
+        self, tmp_path, get_file
+    ):
         runner = CliRunner()
         output_path = tmp_path / "bla.rvt"
         params = [
-            get_local_testdata("raven-routing-sample/era5-test-dataset-crop.nc"),
-            get_local_testdata("raven-routing-sample/finalcat_hru_info.zip"),
+            get_file(
+                "raven-routing-sample/era5-test-dataset-crop.nc",
+            ),
+            get_file(
+                "raven-routing-sample/finalcat_hru_info.zip",
+            ),
             "--var-names",
             "longitude",
             "latitude",
@@ -96,12 +111,12 @@ class TestGenerateGridWeights:
         weight = float(re.search("4 3731 (.+)", output).group(1))
         assert abs(weight - 0.0034512752779023515) < 1e-04
 
-    def test_generate_grid_weights_with_shp_input(self, tmp_path):
+    def test_generate_grid_weights_with_shp_input(self, tmp_path, get_file):
         runner = CliRunner()
         output_path = tmp_path / "bla.rvt"
         params = [
-            get_local_testdata("raven-routing-sample/OTT_sub.zip"),
-            get_local_testdata("raven-routing-sample/finalcat_hru_info.zip"),
+            get_file("raven-routing-sample/OTT_sub.zip"),
+            get_file("raven-routing-sample/finalcat_hru_info.zip"),
             "-o",
             output_path,
         ]
@@ -122,12 +137,14 @@ class TestGenerateGridWeights:
         weight = float(re.search("13 238 (.+)", output).group(1))
         assert abs(weight - 0.5761414847779369) < 1e-04
 
-    def test_generate_grid_weights_with_weight_rescaling(self, tmp_path):
+    def test_generate_grid_weights_with_weight_rescaling(self, tmp_path, get_file):
         runner = CliRunner()
         output_path = tmp_path / "bla.rvt"
         params = [
-            get_local_testdata("raven-routing-sample/OTT_sub.zip"),
-            get_local_testdata("raven-routing-sample/finalcat_hru_info.zip"),
+            get_file("raven-routing-sample/OTT_sub.zip"),
+            get_file(
+                "raven-routing-sample/finalcat_hru_info.zip",
+            ),
             "--area-error-threshold",
             "0.42",
             "-o",
@@ -152,13 +169,17 @@ class TestGenerateGridWeights:
 
 
 class TestAggregateForcingsToHRUs:
-    def test_aggregate_forcings_to_hrus(self, tmp_path):
+    def test_aggregate_forcings_to_hrus(self, tmp_path, get_file):
         runner = CliRunner()
         output_nc_file_path = tmp_path / "aggreg.nc"
         output_weight_file_path = tmp_path / "weight_aggreg.rvt"
         params = [
-            get_local_testdata("raven-routing-sample/VIC_streaminputs.nc"),
-            get_local_testdata("raven-routing-sample/VIC_streaminputs_weights.rvt"),
+            get_file(
+                "raven-routing-sample/VIC_streaminputs.nc",
+            ),
+            get_file(
+                "raven-routing-sample/VIC_streaminputs_weights.rvt",
+            ),
             "-v",
             "Streaminputs",
             "--output-nc-file",
@@ -202,13 +223,13 @@ class TestAggregateForcingsToHRUs:
         assert abs(val[0, 50] - 0.010276) < 1e-04
         assert abs(val[16071, 50] - 0.516639) < 1e-04
 
-    def test_aggregate_forcings_to_hrus_with_nodata(self, tmp_path):
+    def test_aggregate_forcings_to_hrus_with_nodata(self, tmp_path, get_file):
         runner = CliRunner()
         output_nc_file_path = tmp_path / "aggreg.nc"
         output_weight_file_path = tmp_path / "weight_aggreg.rvt"
         params = [
-            get_local_testdata("raven-routing-sample/VIC_test_nodata.nc"),
-            get_local_testdata("raven-routing-sample/VIC_test_nodata_weights.rvt"),
+            get_file("raven-routing-sample/VIC_test_nodata.nc"),
+            get_file("raven-routing-sample/VIC_test_nodata_weights.rvt"),
             "-v",
             "et",
             "--dim-names",
