@@ -12,6 +12,7 @@ class TestRemoteFileAccess:
     git_url = "https://github.com/Ouranosinc/raven-testdata"
     branch = "master"
 
+    @pytest.mark.online
     def test_get_file_default_cache(self):
         file = get_file(name="ostrich-hbvec/raven-hbvec-salmon.rvi", branch=self.branch)
 
@@ -21,6 +22,7 @@ class TestRemoteFileAccess:
             header = f.read()
             assert ":FileType          rvi ASCII Raven 2.8.2" in header
 
+    @pytest.mark.online
     def test_open_dataset(self):
         ds = open_dataset(
             name="raven-gr4j-cemaneige/Salmon-River-Near-Prince-George_meteo_daily.nc",
@@ -38,6 +40,7 @@ class TestRemoteFileAccess:
         )
         assert isinstance(ds, xarray.Dataset)
 
+    @pytest.mark.online
     def test_open_dataset_false_cache(self):
         ds = open_dataset(
             name="raven-gr4j-cemaneige/Salmon-River-Near-Prince-George_meteo_daily_3d.nc",
@@ -55,7 +58,8 @@ class TestRemoteFileAccess:
         )
         assert isinstance(ds, xarray.Dataset)
 
-    @pytest.mark.xfail(reason="test.opendap.org is offline")
+    @pytest.mark.online
+    @pytest.mark.xfail(raises=OSError, reason="test.opendap.org is offline")
     def test_dap_access(self):
         ds = open_dataset(
             name="20070917-MODIS_A-JPL-L2P-A2007260000000.L2_LAC_GHRSST-v01.nc",
@@ -69,11 +73,13 @@ class TestQueryFolder:
     git_url = "https://github.com/Ouranosinc/raven-testdata"
     branch = "master"
 
+    @pytest.mark.online
     @pytest.mark.xfail(reason="Query folder is API rate limited")
     def test_query_specific_folder(self):
         folder = query_folder(folder="raven-gr4j-cemaneige", branch=self.branch)
         assert len(folder) == 8
 
+    @pytest.mark.online
     @pytest.mark.xfail(reason="Query folder is API rate limited")
     def test_query_folder_patterns(self):
         mohyse = query_folder(
@@ -84,6 +90,7 @@ class TestQueryFolder:
             Path("regionalisation_data", "tests", "MOHYSE_parameters.csv")
         )
 
+    @pytest.mark.online
     @pytest.mark.xfail(reason="Query folder is API rate limited")
     def test_query_folder_patterns_excessive_slashes(self):
         mohyse = query_folder(
